package com.hikari.regedist.service

import com.hikari.regedist.PolicyConfiguration
import com.hikari.regedist.entity.PolicyItem
import com.hikari.regedist.support.BusinessError
import gaf3.core.data.PageParam
import gaf3.core.util.DataBeanHelper
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service

@Service
class QueryByPathService(val config: PolicyConfiguration) {

    @Autowired
    lateinit var policyService: PolicyService

    @Autowired
    lateinit var policyItemService: PolicyItemService

    /**
     * 根据路径参数获取策略下的所有策略项或策略项的值
     * @param path 路径参数，默认以'/'分割，路径参数最后一项仍为策略键，返回该策略下所有策略项
     *             若最后一项为策略项键，则返回该策略项的值
     */
    fun findByKeyPath(path: String): Any {
        var keyPath = path
        if (path.startsWith(config.separator)) keyPath = path.substring(1)
        var pid: String? = null
        var result: Any? = null
        val keys = keyPath.split(config.separator).toTypedArray()
        for (i in keys.indices) {
            val policy = policyService.findByKeyAndPid(keys[i], pid)
            policy?.run {
                pid = this.id
            }
            if (i == keys.lastIndex && policy != null) {
                result = mutableListOf<Map<String, String?>>()
                var skip = 0
                val limit = 100
                var total: Int
                do {
                    val paged = PolicyItem().apply {
                        this.policyId = policy.id
                    }.run {
                        policyItemService.find(this, pageParam = PageParam.of(skip, limit))
                    }
                    paged.data?.forEach {
                        (result as MutableList<Map<String, String?>>).add(
                                mapOf(
                                        "id" to it.id,
                                        "name" to it.name,
                                        "key" to it.itemKey,
                                        "value" to it.itemValue,
                                        "type" to it.itemType,
                                        "policyId" to it.policyId,
                                        "orderNum" to it.orderNum?.toString(),
                                        "description" to it.description
                                ))
                    }
                    total = paged.total
                    skip += limit
                } while (skip < total)
            }
            if (i == keys.lastIndex && policy == null && i != 0) {
                policyItemService.findByPolicyIdAndKey(pid!!, keys[keys.lastIndex])?.let {
                    result = mapOf(
                            "id" to it.id,
                            "name" to it.name,
                            "value" to it.itemValue,
                            "key" to it.itemKey,
                            "type" to it.itemType,
                            "policyId" to it.policyId,
                            "orderNum" to it.orderNum?.toString(),
                            "description" to it.description
                    )
                }
            }
            if (i != keys.lastIndex && policy == null)
                break
        }
        if (result == null) throw BusinessError(BusinessError.DATA_NOT_EXIST)
        return result as Any
    }
}