package com.hikari.regedist.support

import org.slf4j.LoggerFactory
import org.springframework.http.HttpStatus
import org.springframework.http.server.reactive.ServerHttpResponse
import org.springframework.web.bind.annotation.ExceptionHandler
import org.springframework.web.bind.annotation.RestControllerAdvice
import javax.validation.ConstraintViolationException

@RestControllerAdvice
class WebControllerAdvice {

    @ExceptionHandler(ConstraintViolationException::class)
    fun validationExceptionHandler(ex: ConstraintViolationException,response:ServerHttpResponse): ErrorResult {
        log.debug("[exception]校验异常:${ex.localizedMessage}")
        response.statusCode = HttpStatus.INTERNAL_SERVER_ERROR
        return ErrorResult().apply {
            this.errCode = -1
            this.errMsg = ex.message?.substring(ex.message!!.indexOf(":") + 2) ?: ""
            this.detils = ex.localizedMessage
        }
    }

    @ExceptionHandler(BusinessError::class)
    fun businessErrorHandler(ex: BusinessError,response:ServerHttpResponse):ErrorResult{
        log.debug("[exception]业务异常:${ex.errMsg}")
        response.statusCode = HttpStatus.INTERNAL_SERVER_ERROR
        return ErrorResult().apply {
            this.errCode = ex.errCode
            this.errMsg = ex.errMsg
            this.detils = ex.details
        }
    }

    companion object {
        val log = LoggerFactory.getLogger(WebControllerAdvice::class.java)
    }
}